import time


def sys_time():
    t1 = time.localtime()
    t2 = time.strftime("%a, %d %b %Y, %H:%M:%S", t1)
    return t2


def mintosec(minutes):
    t = minutes * 60
    return t


def htosec(hours):
    t = hours * 60 * 60
    return t


def daytosec(days):
    t = days * 24 * 60 * 60
    return t


def work_week():
    t = 1 * 5 * 24 * 60 * 60
    return t


def weektosec(weeks):
    t = weeks * 7 * 24 * 60 * 60
    return t


def weekend():
    return 2 * 24 * 60 * 60


def monthtosec(months):
    t = months * 30 * 24 * 60 * 60
    return t


def yeartosec(years):
    t = years * 365 * 24 * 60 * 60
    return t



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Programming Language :: Python :: 3',
    'Operating System :: Microsoft :: Windows :: Windows 10'
]

setup(
    name="timecalculator",
    version="1.1.9",
    packages=find_packages(),
    long_description=open('README.rst').read(),
    author="Xyndra",
    author_email="sammy@deutschergamingserver.de",
    license="MIT",
    url='https://github.com/Xyndra/Timecalculator',
    keywords=["time","calculator"],
    description="A time calculator",
    classifiers=classifiers
)
# twine upload --repository-url https://upload.pypi.org/legacy/ dist/*
# py setup.py sdist